@@ -10,7 +10,7 @@ class Extension:
         self._ipx = ipx
         self._ext_type = ext_type
         self._ext_number = ext_number
-        self._name = ipx.get_obj_name(obj_type, obj_number)
+        self._name = ipx.get_ext_name(ext_type, ext_number)
         self._config = ipx.get_ext_config(ext_type, ext_number)
         self._ext_id = ipx.get_ext_id(ext_type, ext_number)
         self._io_number = io_number
